# Newchanic
This package allows you to easily develop simulators based on Newton's mechanic.  
See [here](http://www.ac-nice.fr/clea/lunap/html/MecaNewton/MecNewEnBref.html) (in french) to better understand it.
Define laws, create particles & bind them to the simulator engine : they will evolute in a 2D graphical interface.   
You can zoom-in using the mouse's scroll and move in the window using arrow keys.